From: Denys Vlasenko <redacted>
Date: Sun, 19 Jul 2015 17:36:00 +0200
This patch deinlines jhash and jhash2.
It also removes rhashtable_jhash2(key, length, seed)
because it was merely calling jhash2(key, length, seed).
With this .config: http://busybox.net/~vda/kernel_config,
after deinlining these functions have sizes and callsite counts
as follows:
jhash: 297 bytes, 111 calls
jhash2: 205 bytes, 136 calls
Total size decrease is about 33,000 bytes:
text data bss dec hex filename
90663567 17221960 36659200 144544727 89d93d7 vmlinux5
90630370 17221864 36659200 144511434 89d11ca vmlinux.after
Signed-off-by: Denys Vlasenko <redacted>
No performance metrics at all have been provided, so this should
not be applied.